@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2023 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -28,7 +28,8 @@
 
 using namespace AppStream;
 
-class AppStream::IconData : public QSharedData {
+class AppStream::IconData : public QSharedData
+{
 public:
     IconData()
     {
@@ -46,40 +47,43 @@ public:
         g_object_unref(m_icon);
     }
 
-    bool operator==(const IconData& rd) const
+    bool operator==(const IconData &rd) const
     {
         return rd.m_icon == m_icon;
     }
 
-    AsIcon *icon() const {
+    AsIcon *icon() const
+    {
         return m_icon;
     }
 
     AsIcon *m_icon;
 };
 
-Icon::Icon(const Icon& other)
+Icon::Icon(const Icon &other)
     : d(other.d)
-{}
+{
+}
 
 Icon::Icon()
     : d(new IconData)
-{}
+{
+}
 
 Icon::Icon(_AsIcon *icon)
     : d(new IconData(icon))
-{}
+{
+}
 
-Icon::~Icon()
-{}
+Icon::~Icon() { }
 
-Icon& Icon::operator=(const Icon& other)
+Icon &Icon::operator=(const Icon &other)
 {
     this->d = other.d;
     return *this;
 }
 
-AsIcon * AppStream::Icon::asIcon() const
+AsIcon *AppStream::Icon::cPtr() const
 {
     return d->icon();
 }
@@ -99,7 +103,8 @@ uint Icon::height() const
     return as_icon_get_height(d->m_icon);
 }
 
-void Icon::setHeight(uint height) {
+void Icon::setHeight(uint height)
+{
     as_icon_set_height(d->m_icon, height);
 }
 
@@ -113,7 +118,7 @@ void Icon::setWidth(uint width)
     as_icon_set_width(d->m_icon, width);
 }
 
-void Icon::setUrl(const QUrl& url)
+void Icon::setUrl(const QUrl &url)
 {
     if (url.isLocalFile())
         as_icon_set_filename(d->m_icon, qPrintable(url.toString()));
@@ -121,7 +126,8 @@ void Icon::setUrl(const QUrl& url)
         as_icon_set_url(d->m_icon, qPrintable(url.toString()));
 }
 
-const QUrl Icon::url() const {
+const QUrl Icon::url() const
+{
     if (as_icon_get_kind(d->m_icon) == AS_ICON_KIND_REMOTE)
         return QUrl(as_icon_get_url(d->m_icon));
     else
@@ -133,7 +139,7 @@ const QString Icon::name() const
     return valueWrap(as_icon_get_name(d->m_icon));
 }
 
-void Icon::setName(const QString& name)
+void Icon::setName(const QString &name)
 {
     as_icon_set_name(d->m_icon, qPrintable(name));
 }
@@ -148,7 +154,8 @@ QSize AppStream::Icon::size() const
     return QSize(width(), height());
 }
 
-QDebug operator<<(QDebug s, const AppStream::Icon& image) {
+QDebug operator<<(QDebug s, const AppStream::Icon &image)
+{
     s.nospace() << "AppStream::Icon(" << image.kind();
     if (!image.url().isEmpty())
         s.nospace() << ',' << image.url();
