@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2014  Sune Vuorela <sune@vuorela.dk>
- * Copyright (C) 2016 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2023 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -30,7 +30,8 @@
 
 using namespace AppStream;
 
-class AppStream::ProvidedData : public QSharedData {
+class AppStream::ProvidedData : public QSharedData
+{
 public:
     ProvidedData()
     {
@@ -48,7 +49,7 @@ public:
         g_object_unref(m_prov);
     }
 
-    bool operator==(const ProvidedData& rd) const
+    bool operator==(const ProvidedData &rd) const
     {
         return rd.m_prov == m_prov;
     }
@@ -66,44 +67,46 @@ QString Provided::kindToString(Provided::Kind kind)
     return valueWrap(as_provided_kind_to_string((AsProvidedKind) kind));
 }
 
-Provided::Kind Provided::stringToKind(const QString& kindString)
+Provided::Kind Provided::stringToKind(const QString &kindString)
 {
     return Provided::Kind(as_provided_kind_from_string(qPrintable(kindString)));
 }
 
-Provided::Provided(const Provided& other)
+Provided::Provided(const Provided &other)
     : d(other.d)
-{}
+{
+}
 
 Provided::Provided(_AsProvided *prov)
     : d(new ProvidedData(prov))
-{}
+{
+}
 
 Provided::Provided()
     : d(new ProvidedData)
-{}
+{
+}
 
-Provided::~Provided()
-{}
+Provided::~Provided() { }
 
-Provided& Provided::operator=(const Provided& other)
+Provided &Provided::operator=(const Provided &other)
 {
     this->d = other.d;
     return *this;
 }
 
-bool Provided::operator==(const Provided& other) const
+bool Provided::operator==(const Provided &other) const
 {
-    if(d == other.d) {
+    if (d == other.d) {
         return true;
     }
-    if(d && other.d) {
+    if (d && other.d) {
         return *d == *other.d;
     }
     return false;
 }
 
-_AsProvided * AppStream::Provided::asProvided() const
+_AsProvided *AppStream::Provided::cPtr() const
 {
     return d->provided();
 }
@@ -118,9 +121,9 @@ QStringList Provided::items() const
     return valueWrap(as_provided_get_items(d->m_prov));
 }
 
-bool Provided::hasItem(const QString& item) const
+bool Provided::hasItem(const QString &item) const
 {
-    return as_provided_has_item (d->m_prov, qPrintable(item));
+    return as_provided_has_item(d->m_prov, qPrintable(item));
 }
 
 bool Provided::isEmpty() const
@@ -131,7 +134,8 @@ bool Provided::isEmpty() const
     return array->len == 0;
 }
 
-QDebug operator<<(QDebug s, const AppStream::Provided& Provided) {
+QDebug operator<<(QDebug s, const AppStream::Provided &Provided)
+{
     s.nospace() << "AppStream::Provided(" << Provided.kind() << ',' << Provided.items() << "])";
     return s.space();
 }
