@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2012-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2012-2023 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -22,31 +22,28 @@
 #define __AS_CONTEXT_PRIVATE_H
 
 #include "as-context.h"
-#include "as-component.h"
 #include "as-curl.h"
 
 G_BEGIN_DECLS
 #pragma GCC visibility push(hidden)
 
-const gchar		*as_context_get_architecture (AsContext *ctx);
-void			as_context_set_architecture (AsContext *ctx,
-						     const gchar *value);
+const gchar	      *as_context_get_architecture (AsContext *ctx);
+void		       as_context_set_architecture (AsContext *ctx, const gchar *value);
 
-gboolean		as_context_get_internal_mode (AsContext *ctx);
-void			as_context_set_internal_mode (AsContext *ctx,
-						      gboolean enabled);
+gboolean	       as_context_get_internal_mode (AsContext *ctx);
+void		       as_context_set_internal_mode (AsContext *ctx, gboolean enabled);
 
-const gchar		*as_context_localized_ht_get (AsContext *ctx,
-						      GHashTable *lht,
-						      const gchar *locale_override,
-						      AsValueFlags value_flags);
-void			as_context_localized_ht_set (AsContext *ctx,
-						     GHashTable *lht,
-						     const gchar *value,
-						     const gchar *locale);
+const gchar	      *as_context_localized_ht_get (AsContext	*ctx,
+						    GHashTable	*lht,
+						    const gchar *locale_override);
+void		       as_context_localized_ht_set (AsContext	*ctx,
+						    GHashTable	*lht,
+						    const gchar *value,
+						    const gchar *locale);
 
-AsCurl			*as_context_get_curl (AsContext *ctx,
-					      GError **error);
+AsCurl		      *as_context_get_curl (AsContext *ctx, GError **error);
+
+gboolean	       as_context_os_origin_is_free (AsContext *ctx, const gchar *origin);
 
 #pragma GCC visibility pop
 G_END_DECLS
