@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2020-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2020-2023 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -18,7 +18,7 @@
  * along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#if !defined (AS_COMPILATION)
+#if !defined(AS_COMPILATION)
 #error "Can not use internal AppStream API from external project."
 #endif
 
@@ -49,26 +49,24 @@ typedef enum {
 	AS_CURL_ERROR_LAST
 } AsCurlError;
 
-#define	AS_CURL_ERROR	as_curl_error_quark ()
-GQuark			as_curl_error_quark (void);
+#define AS_CURL_ERROR as_curl_error_quark ()
+GQuark	 as_curl_error_quark (void);
 
-AsCurl			*as_curl_new (GError **error);
+AsCurl	*as_curl_new (GError **error);
 
-void			as_curl_set_cainfo (AsCurl *acurl,
-						const gchar *cainfo);
+void	 as_curl_set_cainfo (AsCurl *acurl, const gchar *cainfo);
 
-GBytes			*as_curl_download_bytes (AsCurl *acurl,
-						 const gchar *url,
-						 GError **error);
-gboolean		as_curl_download_to_filename (AsCurl *acurl,
-							const gchar *url,
-							const gchar *fname,
-							GError **error);
+guint	 as_curl_get_retry_count (AsCurl *acurl);
+void	 as_curl_set_retry_count (AsCurl *acurl, guint count);
 
-gboolean		as_curl_check_url_exists (AsCurl *acurl,
-						  const gchar *url,
-						  GError **error);
+GBytes	*as_curl_download_bytes (AsCurl *acurl, const gchar *url, GError **error);
+gboolean as_curl_download_to_filename (AsCurl	   *acurl,
+				       const gchar *url,
+				       const gchar *fname,
+				       GError	  **error);
 
-gboolean		as_curl_is_url (const gchar *url);
+gboolean as_curl_check_url_exists (AsCurl *acurl, const gchar *url, GError **error);
+
+gboolean as_curl_is_url (const gchar *url);
 
 G_END_DECLS
