@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2023 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -42,7 +42,7 @@
 
 #define YAML_SEPARATOR "---"
 /* Compilers will optimise this to a constant */
-#define YAML_SEPARATOR_LEN strlen(YAML_SEPARATOR)
+#define YAML_SEPARATOR_LEN strlen (YAML_SEPARATOR)
 
 static const gchar *apt_lists_dir = "/var/lib/apt/lists/";
 static const gchar *appstream_yaml_target = "/var/lib/swcatalog/yaml";
@@ -50,8 +50,8 @@ static const gchar *appstream_icons_target = "/var/lib/swcatalog/icons";
 static const gchar *appstream_catalog_root = "/var/lib/swcatalog";
 static const gchar *appstream_catalog_legacy_root = "/var/lib/app-info";
 
-static const gchar* const default_icon_sizes[] = { "48x48", "48x48@2", "64x64", "64x64@2", "128x128", "128x128@2", NULL };
-
+static const gchar *const default_icon_sizes[] = { "48x48",   "48x48@2",   "64x64", "64x64@2",
+						   "128x128", "128x128@2", NULL };
 
 /**
  * directory_is_empty:
@@ -62,18 +62,18 @@ static gboolean
 directory_is_empty (const gchar *dirname)
 {
 	gint n = 0;
-	struct dirent *d;
-	DIR *dir = opendir (dirname);
+	const gchar *d;
+	GDir *dir = g_dir_open (dirname, 0, NULL);
 
 	if (dir == NULL)
 		return TRUE;
 
-	while ((d = readdir (dir)) != NULL) {
+	while ((d = g_dir_read_name (dir)) != NULL) {
 		if (++n > 2)
 			break;
 	}
 
-	closedir (dir);
+	g_dir_close (dir);
 
 	/* empty directory contains . and .. */
 	if (n <= 2)
@@ -90,7 +90,7 @@ directory_is_empty (const gchar *dirname)
  * slower than just loading the initial parts of the file and
  * extracting the origin manually.
  */
-static gchar*
+static gchar *
 as_get_yml_data_origin (const gchar *fname)
 {
 	const gchar *data;
@@ -110,18 +110,21 @@ as_get_yml_data_origin (const gchar *fname)
 	fistream = g_file_read (file, NULL, &err);
 
 	if (!fistream) {
-		g_critical ("Unable to open file '%s' for reading: %s, skipping.", fname, err->message);
+		g_critical ("Unable to open file '%s' for reading: %s, skipping.",
+			    fname,
+			    err->message);
 		g_error_free (err);
 		return NULL;
 	}
 
-	mem_os = (GMemoryOutputStream*) g_memory_output_stream_new (NULL, 0, g_realloc, g_free);
+	mem_os = (GMemoryOutputStream *) g_memory_output_stream_new (NULL, 0, g_realloc, g_free);
 	zdecomp = g_zlib_decompressor_new (G_ZLIB_COMPRESSOR_FORMAT_GZIP);
-	conv_stream = g_converter_input_stream_new (G_INPUT_STREAM (fistream), G_CONVERTER (zdecomp));
+	conv_stream = g_converter_input_stream_new (G_INPUT_STREAM (fistream),
+						    G_CONVERTER (zdecomp));
 	g_object_unref (zdecomp);
 
 	g_output_stream_splice (G_OUTPUT_STREAM (mem_os), conv_stream, 0, NULL, NULL);
-	data = (const gchar*) g_memory_output_stream_get_data (mem_os);
+	data = (const gchar *) g_memory_output_stream_get_data (mem_os);
 
 	/* faster than a regular expression?
 	 * Get the first YAML document, then extract the origin string.
@@ -161,6 +164,48 @@ as_get_yml_data_origin (const gchar *fname)
 	return origin;
 }
 
+/**
+ * as_apt_list_get_icon_tarball_path:
+ */
+static gchar *
+as_apt_list_get_icon_tarball_path (const gchar *lists_dir,
+				   const gchar *basename,
+				   const gchar *size_str)
+{
+	g_autofree gchar *escaped_size = NULL;
+	g_autofree gchar *icons_tarball = NULL;
+
+	escaped_size = g_uri_escape_string (size_str, NULL, FALSE);
+	icons_tarball = g_strdup_printf ("%s/%sicons-%s.tar.zst",
+					 lists_dir,
+					 basename,
+					 escaped_size);
+	if (g_file_test (icons_tarball, G_FILE_TEST_EXISTS))
+		return g_steal_pointer (&icons_tarball);
+
+	g_free (icons_tarball);
+	icons_tarball = g_strdup_printf ("%s/%sicons-%s.tar.gz", lists_dir, basename, escaped_size);
+	if (g_file_test (icons_tarball, G_FILE_TEST_EXISTS))
+		return g_steal_pointer (&icons_tarball);
+
+	/* we couldn't find the file */
+	return NULL;
+}
+
+/**
+ * as_apt_list_icon_tarball_exists:
+ */
+static gboolean
+as_apt_list_icon_tarball_exists (const gchar *lists_dir,
+				 const gchar *basename,
+				 const gchar *size_str)
+{
+	g_autofree gchar *path = NULL;
+	path = as_apt_list_get_icon_tarball_path (lists_dir, basename, size_str);
+
+	return path != NULL;
+}
+
 /**
  * as_extract_icon_cache_tarball:
  */
@@ -170,14 +215,12 @@ as_extract_icon_cache_tarball (const gchar *asicons_target,
 			       const gchar *apt_basename,
 			       const gchar *icons_size)
 {
-	g_autofree gchar *escaped_size = NULL;
 	g_autofree gchar *icons_tarball = NULL;
 	g_autofree gchar *target_dir = NULL;
 	g_autoptr(GError) tmp_error = NULL;
 
-	escaped_size = g_uri_escape_string (icons_size, NULL, FALSE);
-	icons_tarball = g_strdup_printf ("%s/%sicons-%s.tar.gz", apt_lists_dir, apt_basename, escaped_size);
-	if (!g_file_test (icons_tarball, G_FILE_TEST_EXISTS)) {
+	icons_tarball = as_apt_list_get_icon_tarball_path (apt_lists_dir, apt_basename, icons_size);
+	if (icons_tarball == NULL) {
 		/* no icons found, stop here */
 		return;
 	}
@@ -189,7 +232,8 @@ as_extract_icon_cache_tarball (const gchar *asicons_target,
 	}
 
 	if (!as_utils_extract_tarball (icons_tarball, target_dir, &tmp_error))
-		g_debug ("ERROR: Unable to extract AppStream icon tarball from APT cache: %s", tmp_error->message);
+		g_debug ("ERROR: Unable to extract AppStream icon tarball from APT cache: %s",
+			 tmp_error->message);
 }
 
 /**
@@ -201,7 +245,7 @@ as_pool_check_file_newer_than_cache (AsPool *pool, GPtrArray *file_list)
 	struct stat sb = { .st_ctime = 0 };
 
 	for (guint i = 0; i < file_list->len; i++) {
-		const gchar *fname = (const gchar*) g_ptr_array_index (file_list, i);
+		const gchar *fname = (const gchar *) g_ptr_array_index (file_list, i);
 		if (stat (fname, &sb) == -1)
 			continue;
 		if (sb.st_ctime > as_pool_get_os_metadata_cache_age (pool)) {
@@ -241,19 +285,25 @@ as_pool_scan_apt (AsPool *pool, gboolean force, GError **error)
 
 		/* we can't modify the files here if we don't have write access */
 		if (!as_utils_is_writable (appstream_yaml_target)) {
-			g_debug ("Unable to write to '%s': Can't add AppStream data from APT to the pool.", appstream_yaml_target);
+			g_debug ("Unable to write to '%s': Can't add AppStream data from APT to "
+				 "the pool.",
+				 appstream_yaml_target);
 			return;
 		}
 
-		ytfiles = as_utils_find_files_matching (appstream_yaml_target, "*", FALSE, &tmp_error);
+		ytfiles = as_utils_find_files_matching (appstream_yaml_target,
+							"*",
+							FALSE,
+							&tmp_error);
 		if (tmp_error != NULL) {
-			g_warning ("Could not scan for broken symlinks in DEP-11 target: %s", tmp_error->message);
+			g_warning ("Could not scan for broken symlinks in DEP-11 target: %s",
+				   tmp_error->message);
 			return;
 		}
 
 		if (ytfiles != NULL) {
 			for (guint i = 0; i < ytfiles->len; i++) {
-				const gchar *fname = (const gchar*) g_ptr_array_index (ytfiles, i);
+				const gchar *fname = (const gchar *) g_ptr_array_index (ytfiles, i);
 				if (!g_file_test (fname, G_FILE_TEST_EXISTS)) {
 					g_remove (fname);
 					data_changed = TRUE;
@@ -262,9 +312,13 @@ as_pool_scan_apt (AsPool *pool, gboolean force, GError **error)
 		}
 	}
 
-	yml_files = as_utils_find_files_matching (apt_lists_dir, "*Components-*.yml.gz", FALSE, &tmp_error);
+	yml_files = as_utils_find_files_matching (apt_lists_dir,
+						  "*Components-*.yml.gz",
+						  FALSE,
+						  &tmp_error);
 	if (tmp_error != NULL) {
-		g_warning ("Could not scan for APT-downloaded DEP-11 files: %s", tmp_error->message);
+		g_warning ("Could not scan for APT-downloaded DEP-11 files: %s",
+			   tmp_error->message);
 		return;
 	}
 
@@ -284,7 +338,7 @@ as_pool_scan_apt (AsPool *pool, gboolean force, GError **error)
 	for (guint i = 0; i < yml_files->len; i++) {
 		g_autofree gchar *fbasename = NULL;
 		g_autofree gchar *dest_fname = NULL;
-		const gchar *fname = (const gchar*) g_ptr_array_index (yml_files, i);
+		const gchar *fname = (const gchar *) g_ptr_array_index (yml_files, i);
 
 		fbasename = g_path_get_basename (fname);
 		dest_fname = g_build_filename (appstream_yaml_target, fbasename, NULL);
@@ -296,18 +350,16 @@ as_pool_scan_apt (AsPool *pool, gboolean force, GError **error)
 
 		if (!icons_available) {
 			g_autofree gchar *apt_basename = NULL;
-			guint j;
 
 			/* get base prefix for this file in the APT download cache */
-			apt_basename = g_strndup (fbasename, strlen (fbasename) - strlen (g_strrstr (fbasename, "_") + 1));
+			apt_basename = g_strndup (fbasename,
+						  strlen (fbasename) -
+						      strlen (g_strrstr (fbasename, "_") + 1));
 
-			for (j = 0; default_icon_sizes[j] != NULL; j++) {
-				g_autofree gchar *icons_tarball = NULL;
-
-				/* NOTE: We would normally need to escape the "@" of HiDPI icons here, but since having only HiDPI icons is
-				 * a case that never happens and the 64x64px icons are required to be present anyway, we ignore that fact. */
-				icons_tarball = g_strdup_printf ("%s/%sicons-%s.tar.gz", apt_lists_dir, apt_basename, default_icon_sizes[j]);
-				if (g_file_test (icons_tarball, G_FILE_TEST_EXISTS)) {
+			for (guint j = 0; default_icon_sizes[j] != NULL; j++) {
+				if (as_apt_list_icon_tarball_exists (apt_lists_dir,
+								     apt_basename,
+								     default_icon_sizes[j])) {
 					icons_available = TRUE;
 					break;
 				}
@@ -344,15 +396,25 @@ as_pool_scan_apt (AsPool *pool, gboolean force, GError **error)
 
 		/* create YAML target directory */
 		if (g_mkdir_with_parents (appstream_yaml_target, 0755) > 0) {
-			g_warning ("Unable to create '%s': %s", appstream_yaml_target, g_strerror (errno));
+			g_warning ("Unable to create '%s': %s",
+				   appstream_yaml_target,
+				   g_strerror (errno));
 			return;
 		}
 
 		/* create compatibility symlink for old location */
 		if (!g_file_test (appstream_catalog_legacy_root, G_FILE_TEST_EXISTS)) {
-			if (symlink (appstream_catalog_root, appstream_catalog_legacy_root) != 0)
+			g_autoptr(GFile) symfile_legacy_catalog = NULL;
+
+			symfile_legacy_catalog = g_file_new_for_path (
+			    appstream_catalog_legacy_root);
+			if (!g_file_make_symbolic_link (symfile_legacy_catalog,
+							appstream_catalog_root,
+							NULL,
+							NULL))
 				g_debug ("Unable to create compatibility symlink '%s': %s",
-					 appstream_catalog_legacy_root, g_strerror (errno));
+					 appstream_catalog_legacy_root,
+					 g_strerror (errno));
 		}
 	}
 
@@ -361,8 +423,7 @@ as_pool_scan_apt (AsPool *pool, gboolean force, GError **error)
 		g_autofree gchar *dest_fname = NULL;
 		g_autofree gchar *origin = NULL;
 		g_autofree gchar *file_baseprefix = NULL;
-		guint j;
-		const gchar *fname = (const gchar*) g_ptr_array_index (yml_files, i);
+		const gchar *fname = (const gchar *) g_ptr_array_index (yml_files, i);
 
 		fbasename = g_path_get_basename (fname);
 		dest_fname = g_build_filename (appstream_yaml_target, fbasename, NULL);
@@ -372,17 +433,22 @@ as_pool_scan_apt (AsPool *pool, gboolean force, GError **error)
 			g_debug ("File %s is a broken symlink, skipping.", fname);
 			continue;
 		} else if (!g_file_test (dest_fname, G_FILE_TEST_EXISTS)) {
+			g_autoptr(GFile) sym_file = NULL;
+
 			/* file not found, let's symlink */
-			if (symlink (fname, dest_fname) != 0) {
+			sym_file = g_file_new_for_path (dest_fname);
+			if (!g_file_make_symbolic_link (sym_file, fname, NULL, NULL)) {
 				g_debug ("Unable to set symlink (%s -> %s): %s",
-							fname,
-							dest_fname,
-							g_strerror (errno));
+					 dest_fname,
+					 fname,
+					 g_strerror (errno));
 				continue;
 			}
 		} else if (!g_file_test (dest_fname, G_FILE_TEST_IS_SYMLINK)) {
 			/* file found, but it isn't a symlink, try to rescue */
-			g_debug ("Regular file '%s' found, which doesn't belong there. Removing it.", dest_fname);
+			g_debug (
+			    "Regular file '%s' found, which doesn't belong there. Removing it.",
+			    dest_fname);
 			g_remove (dest_fname);
 			continue;
 		}
@@ -395,14 +461,16 @@ as_pool_scan_apt (AsPool *pool, gboolean force, GError **error)
 		}
 
 		/* get base prefix for this file in the APT download cache */
-		file_baseprefix = g_strndup (fbasename, strlen (fbasename) - strlen (g_strrstr (fbasename, "_") + 1));
+		file_baseprefix = g_strndup (fbasename,
+					     strlen (fbasename) -
+						 strlen (g_strrstr (fbasename, "_") + 1));
 
 		/* extract icons to their destination (if they exist at all */
-		for (j = 0; default_icon_sizes[j] != NULL; j++) {
+		for (guint j = 0; default_icon_sizes[j] != NULL; j++) {
 			as_extract_icon_cache_tarball (appstream_icons_target,
-							origin,
-							file_baseprefix,
-							default_icon_sizes[j]);
+						       origin,
+						       file_baseprefix,
+						       default_icon_sizes[j]);
 		}
 	}
 
