@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2014-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2014-2023 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -28,15 +28,10 @@
 G_BEGIN_DECLS
 #pragma GCC visibility push(hidden)
 
-gboolean		as_icon_load_from_xml (AsIcon *icon,
-						AsContext *ctx,
-						xmlNode *node,
-						GError **error);
-void			as_icon_to_xml_node (AsIcon *icon,
-						AsContext *ctx,
-						xmlNode *root);
+gboolean as_icon_load_from_xml (AsIcon *icon, AsContext *ctx, xmlNode *node, GError **error);
+void	 as_icon_to_xml_node (AsIcon *icon, AsContext *ctx, xmlNode *root);
 
-/* NOTE: For YAML, icons are loaded in AsComponent, because the YAML makes this the better option. */
+/* NOTE: For YAML, icons are loaded in AsComponent, due to how YAML is structured. */
 
 #pragma GCC visibility pop
 G_END_DECLS
