@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2019-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2019-2023 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -28,21 +28,11 @@
 G_BEGIN_DECLS
 #pragma GCC visibility push(hidden)
 
-gboolean	as_issue_load_from_xml (AsIssue *issue,
-					AsContext *ctx,
-					xmlNode *node,
-					GError **error);
-void		as_issue_to_xml_node (AsIssue *issue,
-				       AsContext *ctx,
-				       xmlNode *root);
+gboolean as_issue_load_from_xml (AsIssue *issue, AsContext *ctx, xmlNode *node, GError **error);
+void	 as_issue_to_xml_node (AsIssue *issue, AsContext *ctx, xmlNode *root);
 
-gboolean	as_issue_load_from_yaml (AsIssue *issue,
-					    AsContext *ctx,
-					    GNode *node,
-					    GError **error);
-void		as_issue_emit_yaml (AsIssue *issue,
-					AsContext *ctx,
-					yaml_emitter_t *emitter);
+gboolean as_issue_load_from_yaml (AsIssue *issue, AsContext *ctx, GNode *node, GError **error);
+void	 as_issue_emit_yaml (AsIssue *issue, AsContext *ctx, yaml_emitter_t *emitter);
 
 #pragma GCC visibility pop
 G_END_DECLS
