@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2014-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2014-2023 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -30,17 +30,13 @@ G_BEGIN_DECLS
 
 /* NOTE: The AsComponent load the AsLaunchable from XML, because it needs to aggregate multiple tags in one object. */
 
-void		as_launchable_to_xml_node (AsLaunchable *launchable,
-					AsContext *ctx,
-					xmlNode *root);
+void	 as_launchable_to_xml_node (AsLaunchable *launchable, AsContext *ctx, xmlNode *root);
 
-gboolean	as_launchable_load_from_yaml (AsLaunchable *launch,
-						AsContext *ctx,
-						GNode *node,
-						GError **error);
-void		as_launchable_emit_yaml (AsLaunchable *launch,
-					 AsContext *ctx,
-					 yaml_emitter_t *emitter);
+gboolean as_launchable_load_from_yaml (AsLaunchable *launch,
+				       AsContext    *ctx,
+				       GNode	    *node,
+				       GError	   **error);
+void	 as_launchable_emit_yaml (AsLaunchable *launch, AsContext *ctx, yaml_emitter_t *emitter);
 
 #pragma GCC visibility pop
 G_END_DECLS
