@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2017-2020 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2017-2023 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -18,7 +18,7 @@
  * along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#if !defined (__APPSTREAM_H) && !defined (AS_COMPILATION)
+#if !defined(__APPSTREAM_H) && !defined(AS_COMPILATION)
 #error "Only <appstream.h> can be included directly."
 #endif
 
@@ -32,16 +32,15 @@ G_BEGIN_DECLS
 #define AS_TYPE_LAUNCHABLE (as_launchable_get_type ())
 G_DECLARE_DERIVABLE_TYPE (AsLaunchable, as_launchable, AS, LAUNCHABLE, GObject)
 
-struct _AsLaunchableClass
-{
-	GObjectClass		parent_class;
+struct _AsLaunchableClass {
+	GObjectClass parent_class;
 	/*< private >*/
-	void (*_as_reserved1)	(void);
-	void (*_as_reserved2)	(void);
-	void (*_as_reserved3)	(void);
-	void (*_as_reserved4)	(void);
-	void (*_as_reserved5)	(void);
-	void (*_as_reserved6)	(void);
+	void (*_as_reserved1) (void);
+	void (*_as_reserved2) (void);
+	void (*_as_reserved3) (void);
+	void (*_as_reserved4) (void);
+	void (*_as_reserved5) (void);
+	void (*_as_reserved6) (void);
 };
 
 /**
@@ -54,7 +53,7 @@ struct _AsLaunchableClass
  *
  * Type of launch system the entries belong to.
  **/
-typedef enum  {
+typedef enum {
 	AS_LAUNCHABLE_KIND_UNKNOWN,
 	AS_LAUNCHABLE_KIND_DESKTOP_ID,
 	AS_LAUNCHABLE_KIND_SERVICE,
@@ -64,18 +63,16 @@ typedef enum  {
 	AS_LAUNCHABLE_KIND_LAST
 } AsLaunchableKind;
 
-const gchar		*as_launchable_kind_to_string (AsLaunchableKind kind);
-AsLaunchableKind	as_launchable_kind_from_string (const gchar *kind_str);
+const gchar	*as_launchable_kind_to_string (AsLaunchableKind kind);
+AsLaunchableKind as_launchable_kind_from_string (const gchar *kind_str);
 
-AsLaunchable		*as_launchable_new (void);
+AsLaunchable	*as_launchable_new (void);
 
-AsLaunchableKind	as_launchable_get_kind (AsLaunchable *launch);
-void			as_launchable_set_kind (AsLaunchable *launch,
-						AsLaunchableKind kind);
+AsLaunchableKind as_launchable_get_kind (AsLaunchable *launch);
+void		 as_launchable_set_kind (AsLaunchable *launch, AsLaunchableKind kind);
 
-GPtrArray		*as_launchable_get_entries (AsLaunchable *launch);
-void			as_launchable_add_entry (AsLaunchable *launch,
-						const gchar *entry);
+GPtrArray	*as_launchable_get_entries (AsLaunchable *launch);
+void		 as_launchable_add_entry (AsLaunchable *launch, const gchar *entry);
 
 G_END_DECLS
 
