@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2014-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2014-2023 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -30,17 +30,16 @@
 
 #include "as-validator-issue.h"
 
-typedef struct
-{
-	gchar		*tag;
-	AsIssueSeverity	severity;
+typedef struct {
+	gchar *tag;
+	AsIssueSeverity severity;
 
-	gchar		*hint;
-	gchar		*explanation;
+	gchar *hint;
+	gchar *explanation;
 
-	gchar		*fname;
-	gchar		*cid;
-	glong		line;
+	gchar *fname;
+	gchar *cid;
+	glong line;
 } AsValidatorIssuePrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (AsValidatorIssue, as_validator_issue, G_TYPE_OBJECT)
@@ -78,7 +77,7 @@ as_issue_severity_from_string (const gchar *str)
  * Returns: string version of @severity
  *
  **/
-const gchar*
+const gchar *
 as_issue_severity_to_string (AsIssueSeverity severity)
 {
 	if (severity == AS_ISSUE_SEVERITY_ERROR)
@@ -142,7 +141,7 @@ as_validator_issue_class_init (AsValidatorIssueClass *klass)
  *
  * Since: 0.12.8
  **/
-const gchar*
+const gchar *
 as_validator_issue_get_tag (AsValidatorIssue *issue)
 {
 	AsValidatorIssuePrivate *priv = GET_PRIVATE (issue);
@@ -205,7 +204,7 @@ as_validator_issue_set_severity (AsValidatorIssue *issue, AsIssueSeverity severi
  *
  * Since: 0.12.8
  **/
-const gchar*
+const gchar *
 as_validator_issue_get_hint (AsValidatorIssue *issue)
 {
 	AsValidatorIssuePrivate *priv = GET_PRIVATE (issue);
@@ -240,7 +239,7 @@ as_validator_issue_set_hint (AsValidatorIssue *issue, const gchar *hint)
  *
  * Since: 0.12.8
  **/
-const gchar*
+const gchar *
 as_validator_issue_get_explanation (AsValidatorIssue *issue)
 {
 	AsValidatorIssuePrivate *priv = GET_PRIVATE (issue);
@@ -272,7 +271,7 @@ as_validator_issue_set_explanation (AsValidatorIssue *issue, const gchar *explan
  *
  * Returns: a component-id.
  **/
-const gchar*
+const gchar *
 as_validator_issue_get_cid (AsValidatorIssue *issue)
 {
 	AsValidatorIssuePrivate *priv = GET_PRIVATE (issue);
@@ -331,7 +330,7 @@ as_validator_issue_set_line (AsValidatorIssue *issue, glong line)
  *
  * Returns: the filename
  **/
-const gchar*
+const gchar *
 as_validator_issue_get_filename (AsValidatorIssue *issue)
 {
 	AsValidatorIssuePrivate *priv = GET_PRIVATE (issue);
@@ -362,7 +361,7 @@ as_validator_issue_set_filename (AsValidatorIssue *issue, const gchar *fname)
  *
  * Returns: (transfer full): the location hint as string.
  **/
-gchar*
+gchar *
 as_validator_issue_get_location (AsValidatorIssue *issue)
 {
 	AsValidatorIssuePrivate *priv = GET_PRIVATE (issue);
@@ -387,60 +386,6 @@ as_validator_issue_get_location (AsValidatorIssue *issue)
 	return g_string_free (location, FALSE);
 }
 
-/**
- * as_validator_issue_get_importance:
- * @issue: a #AsValidatorIssue instance.
- *
- * This function is deprecated and should not be used in new code.
- *
- * Returns: a #AsIssueSeverity
- **/
-AsIssueSeverity
-as_validator_issue_get_importance (AsValidatorIssue *issue)
-{
-	return as_validator_issue_get_severity (issue);
-}
-
-/**
- * as_validator_issue_set_importance:
- * @issue: a #AsValidatorIssue instance.
- * @importance: the #AsIssueSeverity.
- *
- * This function is deprecated and should not be used in new code.
- **/
-void
-as_validator_issue_set_importance (AsValidatorIssue *issue, AsIssueSeverity importance)
-{
-	as_validator_issue_set_severity (issue, importance);
-}
-
-/**
- * as_validator_issue_get_message:
- * @issue: a #AsValidatorIssue instance.
- *
- * This function is deprecated.
- *
- * Returns: the message
- **/
-const gchar*
-as_validator_issue_get_message (AsValidatorIssue *issue)
-{
-	return as_validator_issue_get_hint (issue);
-}
-
-/**
- * as_validator_issue_set_message:
- * @issue: a #AsValidatorIssue instance.
- * @message: the message text.
- *
- * This function is deprecated.
- **/
-void
-as_validator_issue_set_message (AsValidatorIssue *issue, const gchar *message)
-{
-	as_validator_issue_set_hint (issue, message);
-}
-
 /**
  * as_validator_issue_new:
  *
