@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2019-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2019-2023 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -39,37 +39,37 @@ composecli_add_report_hint (GString *report, AscHint *hint)
 {
 	const gchar *tag = asc_hint_get_tag (hint);
 	switch (asc_hint_get_severity (hint)) {
-		case AS_ISSUE_SEVERITY_ERROR:
-			g_string_append (report, "E: ");
-			break;
-		case AS_ISSUE_SEVERITY_WARNING:
-			g_string_append (report, "W: ");
-			break;
-		case AS_ISSUE_SEVERITY_INFO:
-			g_string_append (report, "I: ");
-			break;
-		case AS_ISSUE_SEVERITY_PEDANTIC:
-			g_string_append (report, "P: ");
-			break;
-		default:
-			g_string_append (report, "U: ");
+	case AS_ISSUE_SEVERITY_ERROR:
+		g_string_append (report, "E: ");
+		break;
+	case AS_ISSUE_SEVERITY_WARNING:
+		g_string_append (report, "W: ");
+		break;
+	case AS_ISSUE_SEVERITY_INFO:
+		g_string_append (report, "I: ");
+		break;
+	case AS_ISSUE_SEVERITY_PEDANTIC:
+		g_string_append (report, "P: ");
+		break;
+	default:
+		g_string_append (report, "U: ");
 	}
 	if (ascli_get_output_colored ()) {
 		switch (asc_hint_get_severity (hint)) {
-			case AS_ISSUE_SEVERITY_ERROR:
-				g_string_append_printf (report, "%c[%dm%s%c[%dm", 0x1B, 31, tag, 0x1B, 0);
-				break;
-			case AS_ISSUE_SEVERITY_WARNING:
-				g_string_append_printf (report, "%c[%dm%s%c[%dm", 0x1B, 33, tag, 0x1B, 0);
-				break;
-			case AS_ISSUE_SEVERITY_INFO:
-				g_string_append_printf (report, "%c[%dm%s%c[%dm", 0x1B, 32, tag, 0x1B, 0);
-				break;
-			case AS_ISSUE_SEVERITY_PEDANTIC:
-				g_string_append_printf (report, "%c[%dm%s%c[%dm", 0x1B, 37, tag, 0x1B, 0);
-				break;
-			default:
-				g_string_append_printf (report, "%c[%dm%s%c[%dm", 0x1B, 35, tag, 0x1B, 0);
+		case AS_ISSUE_SEVERITY_ERROR:
+			g_string_append_printf (report, "%c[%dm%s%c[%dm", 0x1B, 31, tag, 0x1B, 0);
+			break;
+		case AS_ISSUE_SEVERITY_WARNING:
+			g_string_append_printf (report, "%c[%dm%s%c[%dm", 0x1B, 33, tag, 0x1B, 0);
+			break;
+		case AS_ISSUE_SEVERITY_INFO:
+			g_string_append_printf (report, "%c[%dm%s%c[%dm", 0x1B, 32, tag, 0x1B, 0);
+			break;
+		case AS_ISSUE_SEVERITY_PEDANTIC:
+			g_string_append_printf (report, "%c[%dm%s%c[%dm", 0x1B, 37, tag, 0x1B, 0);
+			break;
+		default:
+			g_string_append_printf (report, "%c[%dm%s%c[%dm", 0x1B, 35, tag, 0x1B, 0);
 		}
 	} else {
 		g_string_append (report, tag);
@@ -98,13 +98,20 @@ composecli_print_hints_report (GPtrArray *results, const gchar *title, AscReport
 
 			start_len = report->len;
 			if (ascli_get_output_colored ())
-				g_string_append_printf (report, "\n%c[%dm%s%c[%dm\n", 0x1B, 1, issue_cids[j], 0x1B, 0);
+				g_string_append_printf (report,
+							"\n%c[%dm%s%c[%dm\n",
+							0x1B,
+							1,
+							issue_cids[j],
+							0x1B,
+							0);
 			else
 				g_string_append_printf (report, "\n%s\n", issue_cids[j]);
 
 			for (guint k = 0; k < hints->len; k++) {
 				AscHint *hint = ASC_HINT (g_ptr_array_index (hints, k));
-				if (mode == ASC_REPORT_MODE_ERROR_SUMMARY && !asc_hint_is_error (hint))
+				if (mode == ASC_REPORT_MODE_ERROR_SUMMARY &&
+				    !asc_hint_is_error (hint))
 					continue;
 				/* pedantic hints are usually not important enough to be displayed here */
 				if (asc_hint_get_severity (hint) == AS_ISSUE_SEVERITY_PEDANTIC)
@@ -121,15 +128,17 @@ composecli_print_hints_report (GPtrArray *results, const gchar *title, AscReport
 
 					text = asc_hint_format_explanation (hint);
 					text_md = g_string_new (text);
-					as_gstring_replace (text_md, "<code>", "`");
-					as_gstring_replace (text_md, "</code>", "`");
-					as_gstring_replace (text_md, "<br/>", "\n");
-					as_gstring_replace (text_md, "<em>", "");
-					as_gstring_replace (text_md, "</em>", "");
-					as_gstring_replace (text_md, "&lt;", "<");
-					as_gstring_replace (text_md, "&gt;", ">");
+					as_gstring_replace (text_md, "<code>", "`", 0);
+					as_gstring_replace (text_md, "</code>", "`", 0);
+					as_gstring_replace (text_md, "<br/>", "\n", 0);
+					as_gstring_replace (text_md, "<em>", "", 0);
+					as_gstring_replace (text_md, "</em>", "", 0);
+					as_gstring_replace (text_md, "&lt;", "<", 0);
+					as_gstring_replace (text_md, "&gt;", ">", 0);
 
-					text_md_wrap = ascli_format_long_output (text_md->str, 100, 5);
+					text_md_wrap = ascli_format_long_output (text_md->str,
+										 100,
+										 5);
 					g_string_append (report, text_md_wrap);
 					g_string_append_c (report, '\n');
 				}
@@ -179,53 +188,88 @@ main (int argc, char **argv)
 	GPtrArray *results;
 
 	const GOptionEntry options[] = {
-		{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose,
-			/* TRANSLATORS: ascompose flag description for: --verbose */
-			_("Show extra debugging information"), NULL },
-		{ "no-color", '\0', 0, G_OPTION_ARG_NONE, &no_color,
-			/* TRANSLATORS: ascompose flag description for: --no-color */
-			_("Don\'t show colored output."), NULL },
-		{ "version", '\0', 0, G_OPTION_ARG_NONE, &show_version,
-			/* TRANSLATORS: ascompose flag description for: --version */
-			_("Show the program version."), NULL },
-		{ "no-net", '\0', 0, G_OPTION_ARG_NONE, &no_net,
+		{ "verbose",
+		  'v', 0,
+		  G_OPTION_ARG_NONE, &verbose,
+		  /* TRANSLATORS: ascompose flag description for: --verbose */
+		  _("Show extra debugging information"), NULL },
+		  { "no-color",
+		    '\0', 0,
+		    G_OPTION_ARG_NONE, &no_color,
+		    /* TRANSLATORS: ascompose flag description for: --no-color */
+		    _("Don\'t show colored output."), NULL },
+		    { "version",
+		      '\0', 0,
+		      G_OPTION_ARG_NONE, &show_version,
+		      /* TRANSLATORS: ascompose flag description for: --version */
+		      _("Show the program version."), NULL },
+		      { "no-net",
+			'\0', 0,
+			G_OPTION_ARG_NONE, &no_net,
 			/* TRANSLATORS: ascompose flag description for: --no-net */
 			_("Do not use the network at all, not even for URL validity checks."), NULL },
-		{ "print-report", '\0', 0, G_OPTION_ARG_STRING, &report_mode_str,
-			/* TRANSLATORS: ascompose flag description for: --print-report */
-			_("Set mode of the issue report that is printed to the console"), "MODE" },
-		{ "prefix", '\0', 0, G_OPTION_ARG_FILENAME, &prefix,
-			/* TRANSLATORS: ascompose flag description for: --prefix */
-			_("Override the default prefix (`/usr` by default)"), "DIR" },
-		{ "result-root", '\0', 0, G_OPTION_ARG_FILENAME, &res_root_dir,
-			/* TRANSLATORS: ascompose flag description for: --result-root */
-			_("Set the result output directory"), "DIR" },
-		{ "data-dir", '\0', 0, G_OPTION_ARG_FILENAME, &mdata_dir,
+			{ "print-report",
+		  '\0', 0,
+		  G_OPTION_ARG_STRING, &report_mode_str,
+		  /* TRANSLATORS: ascompose flag description for: --print-report */
+			  _("Set mode of the issue report that is printed to the console"), "MODE" },
+			  { "prefix",
+		    '\0', 0,
+		    G_OPTION_ARG_FILENAME, &prefix,
+		    /* TRANSLATORS: ascompose flag description for: --prefix */
+			    _("Override the default prefix (`/usr` by default)"), "DIR" },
+			    { "result-root",
+		      '\0', 0,
+		      G_OPTION_ARG_FILENAME, &res_root_dir,
+		      /* TRANSLATORS: ascompose flag description for: --result-root */
+			      _("Set the result output directory"), "DIR" },
+			      { "data-dir",
+			'\0', 0,
+			G_OPTION_ARG_FILENAME, &mdata_dir,
 			/* TRANSLATORS: ascompose flag description for: --data-dir, `catalog metadata` is an AppStream term */
-			_("Override the catalog metadata output directory"), "DIR" },
-		{ "icons-dir", '\0', 0, G_OPTION_ARG_FILENAME, &icons_dir,
-			/* TRANSLATORS: ascompose flag description for: --icons-dir */
-			_("Override the icon output directory"), "DIR" },
-		{ "media-dir", '\0', 0, G_OPTION_ARG_FILENAME, &media_dir,
-			/* TRANSLATORS: ascompose flag description for: --media-dir */
-			_("Set the media output directory (for media data to be served by a webserver)"), "DIR" },
-		{ "hints-dir", '\0', 0, G_OPTION_ARG_FILENAME, &hints_dir,
-			/* TRANSLATORS: ascompose flag description for: --hints-dir */
-			_("Set a directory where HTML and text issue reports will be stored"), "DIR" },
-		{ "origin", '\0', 0, G_OPTION_ARG_STRING, &origin,
+				_("Override the catalog metadata output directory"), "DIR" },
+				{ "icons-dir",
+		  '\0', 0,
+		  G_OPTION_ARG_FILENAME, &icons_dir,
+		  /* TRANSLATORS: ascompose flag description for: --icons-dir */
+				  _("Override the icon output directory"), "DIR" },
+				  { "media-dir",
+		    '\0', 0,
+		    G_OPTION_ARG_FILENAME, &media_dir,
+		    /* TRANSLATORS: ascompose flag description for: --media-dir */
+				    _("Set the media output directory (for media data to be served by a webserver)"),
+		       "DIR" },
+				    { "hints-dir",
+		      '\0', 0,
+		      G_OPTION_ARG_FILENAME, &hints_dir,
+		      /* TRANSLATORS: ascompose flag description for: --hints-dir */
+				      _("Set a directory where HTML and text issue reports will be stored"),
+		 "DIR" },
+				      { "origin",
+			'\0', 0,
+			G_OPTION_ARG_STRING, &origin,
 			/* TRANSLATORS: ascompose flag description for: --origin */
-			_("Set the origin name"), "NAME" },
-		{ "media-baseurl", '\0', 0, G_OPTION_ARG_STRING, &media_baseurl,
-			/* TRANSLATORS: ascompose flag description for: --media-baseurl */
-			_("Set the URL where the exported media content will be hosted"), "NAME" },
-		{ "no-partial-urls", '\0', 0, G_OPTION_ARG_NONE, &no_partial_urls,
-			/* TRANSLATORS: ascompose flag description for: --no-partial-urls */
-			_("Makes all URLs in output data complete URLs and avoids the use of a shared URL prefix for all metadata."), NULL },
-		{ "components", '\0', 0, G_OPTION_ARG_STRING, &components_str,
-			/* TRANSLATORS: ascompose flag description for: --components */
-			_("A comma-separated list of component-IDs to accept"), "COMPONENT-IDs" },
-		{ NULL}
-	};
+					_("Set the origin name"), "NAME" },
+					{ "media-baseurl",
+		  '\0', 0,
+		  G_OPTION_ARG_STRING, &media_baseurl,
+		  /* TRANSLATORS: ascompose flag description for: --media-baseurl */
+					  _("Set the URL where the exported media content will be hosted"),
+		     "NAME" },
+					  { "no-partial-urls",
+		    '\0', 0,
+		    G_OPTION_ARG_NONE, &no_partial_urls,
+		    /* TRANSLATORS: ascompose flag description for: --no-partial-urls */
+					    _("Makes all URLs in output data complete URLs and avoids the use of a shared URL prefix for all metadata."),
+		       NULL },
+					    { "components",
+		      '\0', 0,
+		      G_OPTION_ARG_STRING, &components_str,
+		      /* TRANSLATORS: ascompose flag description for: --components */
+					      _("A comma-separated list of component-IDs to accept"),
+		 "COMPONENT-IDs" },
+					      { NULL }
+	       };
 
 	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
@@ -251,7 +295,10 @@ main (int argc, char **argv)
 			ascli_print_stdout (_("AppStream version: %s"), PACKAGE_VERSION);
 		} else {
 			/* TRANSLATORS: Output if appstreamcli --version is run and the CLI and libappstream versions differ. */
-			ascli_print_stdout (_("AppStream CLI tool version: %s\nAppStream library version: %s"), PACKAGE_VERSION, as_version_string ());
+			ascli_print_stdout (
+			    _("AppStream CLI tool version: %s\nAppStream library version: %s"),
+			       PACKAGE_VERSION,
+			       as_version_string ());
 		}
 		return EXIT_SUCCESS;
 	}
@@ -270,12 +317,13 @@ main (int argc, char **argv)
 		report_mode = ASC_REPORT_MODE_NONE;
 	if (report_mode == ASC_REPORT_MODE_UNKNOWN) {
 		/* TRANSLATORS: invalid value for the --print-report CLI option */
-		ascli_print_stderr (_("Invalid value for `--print-report` option: %s\n"
+		ascli_print_stderr (
+		    _("Invalid value for `--print-report` option: %s\n"
 				      "Possible values are:\n"
 				      "`on-error` - only prints a short report if the run failed (default)\n"
 				      "`short` - generates an abridged report\n"
 				      "`full` - a detailed report will be printed"),
-				    report_mode_str);
+		       report_mode_str);
 		return EXIT_FAILURE;
 	}
 
@@ -299,10 +347,13 @@ main (int argc, char **argv)
 		if (argc == 2) {
 			/* we have only one unit as parameter, assume it as target path for convenience & compatibility */
 			res_root_dir = g_strdup (argv[1]);
-			ascli_print_stdout (_("Automatically selected '%s' as data output location."), res_root_dir);
+			ascli_print_stdout (
+			    _("Automatically selected '%s' as data output location."),
+			       res_root_dir);
 		} else {
 			/* TRANSLATORS: We don't have a destination directory for compose */
-			g_printerr ("%s\n", _("No destination directory set, please provide a data output location!"));
+			g_printerr ("%s\n",
+				    _("No destination directory set, please provide a data output location!"));
 			return EXIT_FAILURE;
 		}
 	}
@@ -312,7 +363,10 @@ main (int argc, char **argv)
 		/* TRANSLATORS: Information message of appstream-compose */
 		tmp = g_strdup_printf ("Metadata origin not set, using '%s'", origin);
 		if (ascli_get_output_colored ())
-			ascli_print_stderr ("%c[%dm%s%c[%dm: %s", 0x1B, 33, _("WARNING"), 0x1B, 0, tmp);
+			ascli_print_stderr ("%c[%dm%s%c[%dm: %s",
+					    0x1B,
+					    33,
+					    _("WARNING"), 0x1B, 0, tmp);
 		else
 			ascli_print_stderr ("%s: %s", _("WARNING"), tmp);
 	}
@@ -322,7 +376,11 @@ main (int argc, char **argv)
 		mdata_dir = g_build_filename (res_root_dir, prefix, "share/swcatalog/xml", NULL);
 	asc_compose_set_data_result_dir (compose, mdata_dir);
 	if (icons_dir == NULL)
-		icons_dir = g_build_filename (res_root_dir, prefix, "share/swcatalog/icons", origin, NULL);
+		icons_dir = g_build_filename (res_root_dir,
+					      prefix,
+					      "share/swcatalog/icons",
+					      origin,
+					      NULL);
 	asc_compose_set_icons_result_dir (compose, icons_dir);
 
 	/* optional */
@@ -335,7 +393,7 @@ main (int argc, char **argv)
 		g_autofree gchar *tmp = NULL;
 		tmp = g_option_context_get_help (option_context, TRUE, NULL);
 		g_print ("%s", tmp);
-		return  EXIT_FAILURE;
+		return EXIT_FAILURE;
 	}
 
 	/* add allowlist for components */
@@ -396,11 +454,15 @@ main (int argc, char **argv)
 		/* TRANSLATORS: appstream-compose failed to include all data */
 		g_print ("%s\n", _("Run failed, some data was ignored."));
 		/* TRANSLATORS: information message of appstream-compose */
-		composecli_print_hints_report (results, _("Errors were raised during this compose run:"), report_mode);
-		g_print ("%s\n", _("Refer to the generated issue report data for details on the individual problems."));
+		composecli_print_hints_report (results,
+					       _("Errors were raised during this compose run:"),
+						  report_mode);
+		g_print ("%s\n",
+			 _("Refer to the generated issue report data for details on the individual problems."));
 		return EXIT_FAILURE;
 	} else {
-		composecli_print_hints_report (results, _("Overview of generated hints:"), report_mode);
+		composecli_print_hints_report (results,
+					       _("Overview of generated hints:"), report_mode);
 		/* TRANSLATORS: Information message */
 		g_print ("%s\n", _("Success!"));
 
